package Bencher::ScenarioR::LogGer::OutputStartup;

our $VERSION = 0.005; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 0.00011,
        participant => "init-with-FileWriteRotate",
        rate => 33,
        samples => 20,
        time => 30,
        vs_slowest => 1,
      },
      {
        errors => 3.4e-05,
        participant => "init-with-LogDispatchOutput",
        rate => 58,
        samples => 20,
        time => 17,
        vs_slowest => 1.8,
      },
      {
        errors => 4.6e-05,
        participant => "init-with-Composite",
        rate => 86,
        samples => 20,
        time => 12,
        vs_slowest => 2.6,
      },
      {
        errors => 2.5e-05,
        participant => "init-with-LogAny",
        rate => 86,
        samples => 20,
        time => 12,
        vs_slowest => 2.6,
      },
      {
        errors => 4.5e-05,
        participant => "init-with-DirWriteRotate",
        rate => 110,
        samples => 21,
        time => 9.4,
        vs_slowest => 3.2,
      },
      {
        errors => 2.5e-05,
        participant => "init-with-File",
        rate => 140,
        samples => 20,
        time => 6.9,
        vs_slowest => 4.4,
      },
      {
        errors => 2.3e-05,
        participant => "init-with-ArrayWithLimits",
        rate => 150,
        samples => 22,
        time => 6.9,
        vs_slowest => 4.4,
      },
      {
        errors => 2.6e-05,
        participant => "init-with-Array",
        rate => 150,
        samples => 20,
        time => 6.8,
        vs_slowest => 4.4,
      },
      {
        errors => 1.7e-05,
        participant => "init-with-Screen",
        rate => 150,
        samples => 20,
        time => 6.8,
        vs_slowest => 4.4,
      },
      {
        errors => 2e-05,
        participant => "init-with-Callback",
        rate => 150,
        samples => 21,
        time => 6.8,
        vs_slowest => 4.4,
      },
      {
        errors => 1.2e-05,
        participant => "init-with-String",
        rate => 150,
        samples => 20,
        time => 6.8,
        vs_slowest => 4.5,
      },
      {
        errors => 1.1e-05,
        participant => "init-with-Null",
        rate => 150,
        samples => 20,
        time => 6.6,
        vs_slowest => 4.6,
      },
      {
        errors => 1.1e-05,
        participant => "load-LogDispatchOutput",
        rate => 180,
        samples => 20,
        time => 5.7,
        vs_slowest => 5.3,
      },
      {
        errors => 3.2e-05,
        participant => "load-Composite",
        rate => 210,
        samples => 20,
        time => 4.7,
        vs_slowest => 6.4,
      },
      {
        errors => 1.8e-05,
        participant => "load-LogAny",
        rate => 230,
        samples => 20,
        time => 4.4,
        vs_slowest => 6.9,
      },
      {
        errors => 1e-05,
        participant => "load-Screen",
        rate => 230,
        samples => 20,
        time => 4.3,
        vs_slowest => 7.1,
      },
      {
        errors => 2e-05,
        participant => "load-Callback",
        rate => 230,
        samples => 21,
        time => 4.3,
        vs_slowest => 7.1,
      },
      {
        errors => 1.7e-05,
        participant => "load-FileWriteRotate",
        rate => 230,
        samples => 20,
        time => 4.3,
        vs_slowest => 7.1,
      },
      {
        errors => 2.1e-05,
        participant => "load-File",
        rate => 230,
        samples => 21,
        time => 4.3,
        vs_slowest => 7.1,
      },
      {
        errors => 1.9e-05,
        participant => "load-String",
        rate => 230,
        samples => 21,
        time => 4.3,
        vs_slowest => 7.1,
      },
      {
        errors => 9.6e-06,
        participant => "load-DirWriteRotate",
        rate => 240,
        samples => 20,
        time => 4.2,
        vs_slowest => 7.2,
      },
      {
        errors => 1.6e-05,
        participant => "load-Array",
        rate => 240,
        samples => 21,
        time => 4.2,
        vs_slowest => 7.2,
      },
      {
        errors => 1.4e-05,
        participant => "load-ArrayWithLimits",
        rate => 240,
        samples => 20,
        time => 4.2,
        vs_slowest => 7.2,
      },
      {
        errors => 1.6e-05,
        participant => "load-Null",
        rate => 350,
        samples => 20,
        time => 2.9,
        vs_slowest => 11,
      },
      {
        errors => 1.4e-05,
        participant => "baseline",
        rate => 390,
        samples => 20,
        time => 2.6,
        vs_slowest => 12,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LogGer::OutputStartup",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 0,
                                              speed                        => "3823.140",
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 1,
                                              speed                        => "3806.140",
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 2,
                                              speed                        => 3861.921,
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 3,
                                              speed                        => 3887.421,
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 4,
                                              speed                        => 3891.539,
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 5,
                                              speed                        => 3898.312,
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 6,
                                              speed                        => 3773.335,
                                              stepping                     => 3,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "ida",
                                                                                "arat",
                                                                                "xsaveopt",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "8192 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 60,
                                              name                         => "Intel(R) Core(TM) i7-4770 CPU \@ 3.40GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 8,
                                              processor_id                 => 7,
                                              speed                        => "3863.250",
                                              stepping                     => 3,
                                            },
                                          ],
      "func.elapsed_time"              => 4.94350004196167,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__"                              => 1.036,
                                            "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                            "Benchmark::Dumb"                          => "0.10",
                                            "Devel::Platform::Info"                    => 0.16,
                                            "Log::ger::Output::Array"                  => 0.008,
                                            "Log::ger::Output::ArrayWithLimits"        => 0.001,
                                            "Log::ger::Output::Callback"               => 0.001,
                                            "Log::ger::Output::Composite"              => 0.004,
                                            "Log::ger::Output::DirWriteRotate"         => 0.002,
                                            "Log::ger::Output::File"                   => 0.002,
                                            "Log::ger::Output::FileWriteRotate"        => 0.001,
                                            "Log::ger::Output::LogAny"                 => 0.006,
                                            "Log::ger::Output::LogDispatchOutput"      => 0.001,
                                            "Log::ger::Output::Null"                   => 0.008,
                                            "Log::ger::Output::Screen"                 => 0.004,
                                            "Log::ger::Output::String"                 => 0.008,
                                            "perl"                                     => "v5.24.0",
                                            "Sys::Info"                                => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 24]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "jessie",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.16.0-4-amd64",
                                            kname    => "Linux",
                                            kvers    => "3.16.0-4-amd64",
                                            osflag   => "linux",
                                            oslabel  => "Debian",
                                            osname   => "GNU/Linux",
                                            osvers   => 8.5,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.5 (jessie)\nRelease:\t8.5\nCodename:\tjessie",
                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u1 (2016-09-03) x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.16.0-4-amd64",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::LogGer::OutputStartup",
      "func.scenario_module_md5sum"    => "2d6e617dcb88544eedc582ba2b700d21",
      "func.scenario_module_mtime"     => 1498449729,
      "func.scenario_module_sha1sum"   => "0389ae613ac5ab14f9accef3e8dd982546902675",
      "func.scenario_module_sha256sum" => "0a4e1e5e5c42944c030a62cb5f532fde7cdacd07c6f85077bab8c993aa51ce6f",
      "func.time_end"                  => 1498451477.8725,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1498451472.929,
      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, undef, "/s", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: 

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

